struct ResourceFetchListener {
pending_image_id: PendingImageId,
image_cache: Arc<dyn ImageCache>,
notification: Trusted<Notification>,
status: Result<(), NetworkError>,
url: ServoUrl,
}Fields
pending_image_id: PendingImageIdThe ID of the pending image cache for this request.
image_cache: Arc<dyn ImageCache>A reference to the global image cache.
notification: Trusted<Notification>The notification instance which makes this request.
status: Result<(), NetworkError>Request status that indicates whether this request failed, and the reason.
url: ServoUrlResource URL of this request.